==> openejb-jee-4.0.0-sources.jar: org/apache/openejb/jee/sun/JavaWebStartAccess.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.jee.sun;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "contextRoot",
    "eligible",
    "vendor"
})
public class JavaWebStartAccess {
    @XmlElement(name = "context-root")
    protected String contextRoot;
    protected String eligible;
    protected String vendor;

    public String getContextRoot() {
        return contextRoot;
    }

    public void setContextRoot(String value) {
        this.contextRoot = value;
    }

    public String getEligible() {
        return eligible;
    }

    public void setEligible(String value) {
        this.eligible = value;
    }

    public String getVendor() {
        return vendor;
    }

    public void setVendor(String value) {
        this.vendor = value;
    }
}

==> openejb-jee-8.0.8-sources.jar: org/apache/openejb/jee/sun/JavaWebStartAccess.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.jee.sun;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "contextRoot",
    "eligible",
    "vendor"
})
public class JavaWebStartAccess {
    @XmlElement(name = "context-root")
    protected String contextRoot;
    protected String eligible;
    protected String vendor;

    public String getContextRoot() {
        return contextRoot;
    }

    public void setContextRoot(final String value) {
        this.contextRoot = value;
    }

    public String getEligible() {
        return eligible;
    }

    public void setEligible(final String value) {
        this.eligible = value;
    }

    public String getVendor() {
        return vendor;
    }

    public void setVendor(final String value) {
        this.vendor = value;
    }
}
